Structs
- Memory
Storage - An in-process, non-persistent
StateStoragebacked byDashMap. - State
Context - The FSM context injected into state-matched handlers.
- State
Key - Identifies which conversation slot to read/write state for.
- Storage
Error - An error from a
StateStoragebackend.
Enums
- State
KeyStrategy - How the FSM key is composed from an incoming message.
Traits
- FsmState
- A type that can be used as an FSM state.
- Message
Like - Minimal view of an incoming message needed to build a
StateKey. - State
Storage - Persistent storage backend for FSM state.