pub struct StateKey {
pub user_id: Option<i64>,
pub chat_id: i64,
}Expand description
Identifies which conversation slot to read/write state for.
The canonical strategy is per-user-per-chat so that the same user can have independent sessions in different chats simultaneously.
Fields
user_id: Option<i64>The Telegram user ID, if applicable.
chat_id: i64The Telegram chat ID.
Implementations
Sourceimpl StateKey
impl StateKey
Sourcepub fn from_message(msg: &impl MessageLike, strategy: StateKeyStrategy) -> Self
pub fn from_message(msg: &impl MessageLike, strategy: StateKeyStrategy) -> Self
Construct a key from an incoming message using the given strategy.